Index: Source/core/layout/style/CachedUAStyle.h |
diff --git a/Source/core/layout/style/CachedUAStyle.h b/Source/core/layout/style/CachedUAStyle.h |
index 84facb620f6fb1dc59c5afa8d84a1b8dce56d0d4..4d30ae2bf36955962c620aa32c6c3c53a0a47134 100644 |
--- a/Source/core/layout/style/CachedUAStyle.h |
+++ b/Source/core/layout/style/CachedUAStyle.h |
@@ -22,17 +22,17 @@ |
#ifndef CachedUAStyle_h |
#define CachedUAStyle_h |
-#include "core/layout/style/LayoutStyle.h" |
+#include "core/layout/style/ComputedStyle.h" |
namespace blink { |
// LayoutTheme::adjustStyle wants the background and borders |
// as specified by the UA sheets, excluding any author rules. |
// We use this class to cache those values during |
// applyMatchedProperties for later use during adjustLayoutStyle. |
class CachedUAStyle { |
public: |
- static PassOwnPtr<CachedUAStyle> create(const LayoutStyle* style) |
+ static PassOwnPtr<CachedUAStyle> create(const ComputedStyle* style) |
{ |
return adoptPtr(new CachedUAStyle(style)); |
} |
@@ -42,7 +42,7 @@ public: |
StyleColor backgroundColor; |
private: |
- explicit CachedUAStyle(const LayoutStyle* style) |
+ explicit CachedUAStyle(const ComputedStyle* style) |
: border(style->border()) |
, backgroundLayers(style->backgroundLayers()) |
, backgroundColor(style->backgroundColor()) |
@@ -22,17 +22,17 @@ |
// as specified by the UA sheets, excluding any author rules. |
// We use this class to cache those values during |
-// applyMatchedProperties for later use during adjustLayoutStyle. |
+// applyMatchedProperties for later use during adjustComputedStyle. |
class CachedUAStyle { |
public: |